<?php

$filename = 'c_leitura.php';

if (!file_exists($filename)) {
    header("Location: error.php");
    exit;
}

include 'c_leitura.php';
require_once("db.php");

$idprod = addslashes($_GET['idprod']);
$dono = addslashes($_GET['dono']);
$entrada = 0;
$saida = 0;
$ponto = addslashes($_GET['ponto']);
$data_now = date("Y-m-d H:i:s");


//. "' AND cliente = '" . $dono . "'
$queryResult = "SELECT idprod, cliente FROM tablet WHERE idprod = '" . $idprod ."'" ;
$resultUser = mysql_query($queryResult) or die(mysql_error());
$num_rows = mysql_num_rows($resultUser);


if ($num_rows == 0) {

    $resultPonto = mysql_query("SELECT id FROM ponto WHERE nome = '" . $ponto . "' ");
    $rowPonto = mysql_fetch_array($resultPonto);

    $queryCliente = "SELECT id FROM user WHERE username = '" . $dono . "' ";
    $resulCliente = mysql_query($queryCliente) or die(mysql_error());
    $row = mysql_fetch_array($resulCliente);

    
//Não existe tablet no sistema, cadastrar
//C cadastrar

    $query = "INSERT INTO tablet (idprod, cliente, validade, status, ligado, "
            . "zerar, expiracao, id_ponto, id_apoio, dificuldade,pendrive_id ,cadastro, retencao_slots, dificul_bonus,
            taxa_maxima, acrecimo_taxa_max, periodo_reducao, extras_min_rotina, saldo_para_acumulao, premio_do_acumulado, tam_premio_max, saldo_min_bingo_g1,
            saldo_min_bingo_g2, saldo_min_bingo_g3, qtn_jogos_azar, probabilidada_premios_azar, taxa_max_chance_azar,qtn_jogos_normal,
            probabilidada_premios_normal, taxa_max_chance_normal, qtn_jogos_neutro, probabilidade_premios_neutro, taxa_max_chance_neutro, qtn_jogos_sorte,
            probabilidade_premios_sorte, taxa_max_chance_sorte, qtn_jogos_moderado, probabilidade_premios_moderado, taxa_max_chance_moderado,
            limites_nivel_show_n2, 	limites_nivel_show_n3, 	limites_nivel_show_n4 ) "
            . "VALUES('" . $idprod . "',"
            . " '" . $dono . "', 0, 0, 1, 0, 0, '" . $rowPonto['id'] . "',"
            . " '" . $row['id'] . "' , 65,1,'" . $data_now . "',1 , 20000, 0.55, 0.03, 10000, 50, 100000 , 200, 3, 35000, 50000, 100000, 8 , 0.25, 0, 4, 0.5, 0.03,
             3, 0.25, 0, 5, 0.55, 0.04, 8, 0.55, 0.01, 0.4, 0.2, 0.2 )";

    $result = mysql_query($query) or die(mysql_error());
    echo "C#"
    . $rowPonto['id'] . "#";
} else {

//Existe tablet no sistema atualizar dados no dispositivo
//Pegar a ultima leitura do dispositivo
    $Metrica_query = "SELECT * FROM metricas WHERE idprod = '$idprod' ORDER BY id DESC LIMIT 1";
    $Metrica_result = mysql_query($Metrica_query) or die(mysql_error());
    $Metrica_num_rows = mysql_num_rows($Metrica_result);
    $Metrica_row = mysql_fetch_array($Metrica_result);

    if ($Metrica_num_rows > 0) {
        $entrada = $Metrica_row['entrada'];
        $saida = $Metrica_row['saida'];
    }

//U Update

    echo "U#"
    . $entrada . "#"
    . $saida . "#";
}
?>
